@@ -1776,6 +1776,9 @@ gdm_chooser_gui_init (void)
 static gboolean
 gdm_read_config (void)
 {
+	/* Read config data in bulk */
+	gdmcomm_comm_bulk_start ();
+
 	gdmcomm_set_debug (gdm_config_get_bool (GDM_KEY_DEBUG));
 
 	/*
@@ -1788,7 +1791,6 @@ gdm_read_config (void)
 	gdm_config_get_string (GDM_KEY_DEFAULT_HOST_IMG);
 	gdm_config_get_string (GDM_KEY_HOST_IMAGE_DIR);
 	gdm_config_get_string (GDM_KEY_MULTICAST_ADDR);
-	gdm_config_get_string (GDM_KEY_BROADCAST);
 	gdm_config_get_string (GDM_KEY_BACKGROUND_COLOR);
 	gdm_config_get_int    (GDM_KEY_XINERAMA_SCREEN);
 	gdm_config_get_int    (GDM_KEY_MAX_ICON_WIDTH);
@@ -1796,9 +1798,10 @@ gdm_read_config (void)
 	gdm_config_get_int    (GDM_KEY_SCAN_TIME);
 	gdm_config_get_int    (GDM_KEY_BACKGROUND_TYPE);
 	gdm_config_get_bool   (GDM_KEY_ALLOW_ADD);
+	gdm_config_get_bool   (GDM_KEY_BROADCAST);
 	gdm_config_get_bool   (GDM_KEY_MULTICAST);
 
-	gdmcomm_comm_close();
+	gdmcomm_comm_bulk_stop ();
 }
 
 static gboolean
@@ -1806,6 +1809,9 @@ gdm_reread_config (int sig, gpointer data)
 {
 	/* reparse config stuff here.  At least ones we care about */
 
+	/* Read config data in bulk */
+	gdmcomm_comm_bulk_start ();
+
 	if (gdm_config_reload_bool (GDM_KEY_DEBUG))
 		gdmcomm_set_debug (gdm_config_get_bool (GDM_KEY_DEBUG));
 
@@ -1818,12 +1824,12 @@ gdm_reread_config (int sig, gpointer data)
 	    gdm_config_reload_string (GDM_KEY_DEFAULT_HOST_IMG) ||
 	    gdm_config_reload_string (GDM_KEY_HOST_IMAGE_DIR) ||
 	    gdm_config_reload_string (GDM_KEY_MULTICAST_ADDR) ||
-	    gdm_config_reload_string (GDM_KEY_BROADCAST) ||
 	    gdm_config_reload_int    (GDM_KEY_XINERAMA_SCREEN) ||
 	    gdm_config_reload_int    (GDM_KEY_MAX_ICON_WIDTH) ||
 	    gdm_config_reload_int    (GDM_KEY_MAX_ICON_HEIGHT) ||
 	    gdm_config_reload_int    (GDM_KEY_SCAN_TIME) ||
 	    gdm_config_reload_bool   (GDM_KEY_ALLOW_ADD) ||
+	    gdm_config_reload_bool   (GDM_KEY_BROADCAST) ||
 	    gdm_config_reload_bool   (GDM_KEY_MULTICAST)) {
 
 		if (RUNNING_UNDER_GDM) {
@@ -1842,11 +1848,13 @@ gdm_reread_config (int sig, gpointer data)
 	if (gdm_config_reload_string (GDM_KEY_BACKGROUND_COLOR) ||
 	    gdm_config_reload_int    (GDM_KEY_BACKGROUND_TYPE)) {
 
-		if (gdm_config_get_int (GDM_KEY_BACKGROUND_TYPE) != GDM_BACKGROUND_NONE)
-			gdm_common_setup_background_color (gdm_config_get_string (GDM_KEY_BACKGROUND_COLOR));
+		if (gdm_config_get_int (GDM_KEY_BACKGROUND_TYPE) != GDM_BACKGROUND_NONE) {
+			gdm_common_setup_background_color (gdm_config_get_string
+				(GDM_KEY_BACKGROUND_COLOR));
+		}
 	}
 
-	gdmcomm_comm_close();
+	gdmcomm_comm_bulk_stop ();
 
 	return TRUE;
 }
